#!/sbin/sh
#---------------------------------------------
# Yank555.lu - Kernel options script generator
#---------------------------------------------

script_path="/tmp/Yank555.lu/script"
script_name="init.kernel.sh"
log_file="/data/kernel-script.log"
sub_scripts_path="$script_path/sub-scripts"
props_path="/tmp/aroma"

# Start making the script header -----------------------------------------------------------------

rm $log_file

echo "----------------------------------------------------" >>$log_file
echo "Kernel options init.d script generator by Yank555.lu" >>$log_file
echo "----------------------------------------------------" >>$log_file
date "+Script generated on %d/%m/%Y at %k:%M" >>$log_file
echo "----------------------------------------------------" >>$log_file
echo "" >>$log_file
echo "Preparing init.d script header" >>$log_file

rm $script_path/$script_name >>$log_file
cp $sub_scripts_path/header $script_path/$script_name >>$log_file
date "+# Script generated on %d/%m/%Y at %k:%M" >>$script_path/$script_name
echo "#----------------------------------------------------" >>$script_path/$script_name
echo "" >>$script_path/$script_name

# Add init.d configuration -----------------------------------------------------------------------

echo "" >>$log_file
echo "init.d support configuration" >>$log_file

if [ "`grep selected.1= $props_path/initd.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     init.d support = `grep selected.1= $props_path/initd.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/initd/1.`grep selected.1= $props_path/initd.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
    if [ ! -e /system/etc/init.d ] ; then
        mkdir /system/etc/init.d
        chgrp 2000 /system/etc/init.d
        chmod 755 /system/etc/init.d
        echo "     (init.d folder created)" >>$log_file
    fi
fi;

# Add CPU configuration --------------------------------------------------------------------------

echo "" >>$log_file
echo "CPU configuration" >>$log_file

if [ "`grep selected.1= $props_path/cpugov.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     CPU Governor  = `grep selected.1= $props_path/cpugov.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/cpugov/1.`grep selected.1= $props_path/cpugov.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.2= $props_path/cpugov.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Touchboost    = `grep selected.2= $props_path/cpugov.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/cpugov/2.`grep selected.2= $props_path/cpugov.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.3= $props_path/cpugov.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     CPU Idle Mode = `grep selected.3= $props_path/cpugov.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/cpugov/3.`grep selected.3= $props_path/cpugov.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.4= $props_path/cpugov.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     MC Powersave  = `grep selected.4= $props_path/cpugov.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/cpugov/4.`grep selected.4= $props_path/cpugov.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Add Frequency settings -------------------------------------------------------------------------

if [ "`grep selected.1= $props_path/cpugov.prop | awk -F= '{print $2;}'`" == "3" ]
	then

		if [ "`grep selected.1= $props_path/yankfreq.prop | awk -F= '{print $2;}'`" != "" ]
		  then
		    echo "     YankasusQ frequency   = `grep selected.1= $props_path/yankfreq.prop | awk -F= '{print $2;}'`" >>$log_file
		    cat $sub_scripts_path/yankasus/1.`grep selected.1= $props_path/yankfreq.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
		fi;

		if [ "`grep selected.2= $props_path/yankfreq.prop | awk -F= '{print $2;}'`" != "" ]
		  then
		    echo "     YankasusQ stdby frq.  = `grep selected.2= $props_path/yankfreq.prop | awk -F= '{print $2;}'`" >>$log_file
		    cat $sub_scripts_path/yankasus/2.`grep selected.2= $props_path/yankfreq.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
		fi;

  else

		if [ "`grep selected.1= $props_path/cpufreq.prop | awk -F= '{print $2;}'`" != "" ]
		  then
		    echo "     Other governors freq. = `grep selected.1= $props_path/cpufreq.prop | awk -F= '{print $2;}'`" >>$log_file
		    cat $sub_scripts_path/cpufreq/1.`grep selected.1= $props_path/cpufreq.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
		fi;

		if [ "`grep selected.1= $props_path/cpugov.prop | awk -F= '{print $2;}'`" == "5" ]
			then
				if [ "`grep selected.2= $props_path/cpufreq.prop | awk -F= '{print $2;}'`" != "" ]
				  then
				    echo "     zzmoove profile       = `grep selected.2= $props_path/cpufreq.prop | awk -F= '{print $2;}'`" >>$log_file
				    cat $sub_scripts_path/zzmoove/2.`grep selected.2= $props_path/cpufreq.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
				fi;

				if [ "`grep selected.3= $props_path/cpufreq.prop | awk -F= '{print $2;}'`" != "" ]
				  then
				    echo "     zzmoove standby limit = `grep selected.3= $props_path/cpufreq.prop | awk -F= '{print $2;}'`" >>$log_file
				    cat $sub_scripts_path/zzmoove/3.`grep selected.3= $props_path/cpufreq.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
				fi;

				if [ "`grep selected.4= $props_path/cpufreq.prop | awk -F= '{print $2;}'`" != "" ]
				  then
				    echo "     zzmoove fastscaling   = `grep selected.4= $props_path/cpufreq.prop | awk -F= '{print $2;}'`" >>$log_file
				    cat $sub_scripts_path/zzmoove/4.`grep selected.4= $props_path/cpufreq.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
				fi;

				if [ "`grep selected.5= $props_path/cpufreq.prop | awk -F= '{print $2;}'`" != "" ]
				  then
				    echo "     zzmoove fastscal. off = `grep selected.5= $props_path/cpufreq.prop | awk -F= '{print $2;}'`" >>$log_file
				    cat $sub_scripts_path/zzmoove/5.`grep selected.5= $props_path/cpufreq.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
				fi;

				if [ "`grep selected.6= $props_path/cpufreq.prop | awk -F= '{print $2;}'`" != "" ]
				  then
				    echo "     early demand          = `grep selected.6= $props_path/cpufreq.prop | awk -F= '{print $2;}'`" >>$log_file
				    cat $sub_scripts_path/zzmoove/6.`grep selected.6= $props_path/cpufreq.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
				fi;

				if [ "`grep selected.7= $props_path/cpufreq.prop | awk -F= '{print $2;}'`" != "" ]
				  then
				    echo "     early demand threshld = `grep selected.7= $props_path/cpufreq.prop | awk -F= '{print $2;}'`" >>$log_file
				    cat $sub_scripts_path/zzmoove/7.`grep selected.7= $props_path/cpufreq.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
				fi;
		fi;

fi;

# Virtual memory configuration -------------------------------------------------------------------

echo "" >>$log_file
echo "Virtual memory configuration" >>$log_file

if [ "`grep selected.2= $props_path/swap.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Zram       = `grep selected.2= $props_path/swap.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/swap/2.`grep selected.2= $props_path/swap.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.1= $props_path/swap.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Hardswap   = `grep selected.1= $props_path/swap.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/swap/1.`grep selected.1= $props_path/swap.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.3= $props_path/swap.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Swappiness = `grep selected.3= $props_path/swap.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/swap/3.`grep selected.3= $props_path/swap.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Fast charge configuration ----------------------------------------------------------------------

echo "" >>$log_file
echo "Fast charge configuration" >>$log_file

if [ "`grep selected.1= $props_path/charge.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Mode     = `grep selected.1= $props_path/charge.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/charge/1.`grep selected.1= $props_path/charge.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.2= $props_path/charge.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     USB      = `grep selected.2= $props_path/charge.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/charge/2.`grep selected.2= $props_path/charge.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.3= $props_path/charge.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     AC       = `grep selected.3= $props_path/charge.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/charge/3.`grep selected.3= $props_path/charge.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.4= $props_path/charge.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     wireless = `grep selected.4= $props_path/charge.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/charge/4.`grep selected.4= $props_path/charge.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Add features configuration ---------------------------------------------------------------------

echo "" >>$log_file
echo "features" >>$log_file

if [ "`grep selected.1= $props_path/features.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     fsync support = `grep selected.1= $props_path/features.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/features/1.`grep selected.1= $props_path/features.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.2= $props_path/features.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Touch Wake    = `grep selected.2= $props_path/features.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/features/2.`grep selected.2= $props_path/features.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.3= $props_path/features.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     H/W Key Light Screen   = `grep selected.3= $props_path/features.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/features/3.`grep selected.3= $props_path/features.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.4= $props_path/features.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     H/W Key Light Handling = `grep selected.4= $props_path/features.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/features/4.`grep selected.4= $props_path/features.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Fading Notification LEDs -----------------------------------------------------------------------

echo "" >>$log_file
echo "Fading Notification LEDs" >>$log_file

if [ "`grep selected.1= $props_path/LED.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Fading LED mode      = `grep selected.1= $props_path/LED.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/LED/1.`grep selected.1= $props_path/LED.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.2= $props_path/LED.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Fading LED intensity = `grep selected.2= $props_path/LED.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/LED/2.`grep selected.2= $props_path/LED.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.3= $props_path/LED.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Fading LED speed     = `grep selected.3= $props_path/LED.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/LED/3.`grep selected.3= $props_path/LED.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.4= $props_path/LED.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Fading LED style     = `grep selected.4= $props_path/LED.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/LED/4.`grep selected.4= $props_path/LED.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Add kernel modules loading on boot -------------------------------------------------------------

echo "" >>$log_file
echo "Kernel modules loading on boot" >>$log_file

if [ "`grep selected.1= $props_path/modules.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     cifs kernel modules    = `grep selected.1= $props_path/modules.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/modules/1.`grep selected.1= $props_path/modules.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.2= $props_path/modules.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     nfs kernel modules     = `grep selected.2= $props_path/modules.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/modules/2.`grep selected.2= $props_path/modules.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.3= $props_path/modules.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     ntfs kernel module     = `grep selected.3= $props_path/modules.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/modules/3.`grep selected.3= $props_path/modules.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.4= $props_path/modules.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     isofs kernel module    = `grep selected.4= $props_path/modules.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/modules/4.`grep selected.4= $props_path/modules.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.5= $props_path/modules.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     udf kernel module      = `grep selected.5= $props_path/modules.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/modules/5.`grep selected.5= $props_path/modules.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.6= $props_path/modules.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     xpad kernel module     = `grep selected.6= $props_path/modules.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/modules/6.`grep selected.6= $props_path/modules.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.7= $props_path/modules.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     frandom kernel module  = `grep selected.7= $props_path/modules.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/modules/7.`grep selected.7= $props_path/modules.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Add MMC I/O configuration ----------------------------------------------------------------------

echo "" >>$log_file
echo "MMC I/O configuration" >>$log_file

if [ "`grep selected.1= $props_path/io.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Internal ReadAhead size  = `grep selected.1= $props_path/io.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/io/1.`grep selected.1= $props_path/io.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.2= $props_path/io.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Internal I/O scheduler   = `grep selected.2= $props_path/io.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/io/2.`grep selected.2= $props_path/io.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.3= $props_path/io.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     External ReadAhead size  = `grep selected.3= $props_path/io.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/io/3.`grep selected.3= $props_path/io.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.4= $props_path/io.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     External I/O scheduler   = `grep selected.4= $props_path/io.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/io/4.`grep selected.4= $props_path/io.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Add Android Low Memory Killer configuration ----------------------------------------------------

echo "" >>$log_file
echo "Android Low Memory Killer configuration" >>$log_file

if [ "`grep selected.1= $props_path/lmk.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Android LMK minfree = `grep selected.1= $props_path/lmk.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/lmk/1.`grep selected.1= $props_path/lmk.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Boeffla Sound Engine ---------------------------------------------------------------------------

echo "" >>$log_file
echo "Boeffla Sound Engine configuration" >>$log_file

if [ "`grep selected.1= $props_path/boeffla.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Master Switch      = `grep selected.1= $props_path/boeffla.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/boeffla/1.`grep selected.1= $props_path/boeffla.prop | awk -F= '{print $2;}'` >>$script_path/$script_name

		if [ "`grep selected.1= $props_path/boeffla.prop | awk -F= '{print $2;}'`" == "1" ]
			then
				if [ "`grep selected.2= $props_path/boeffla.prop | awk -F= '{print $2;}'`" != "" ]
				  then
				    echo "     Speaker Output     = `grep selected.2= $props_path/boeffla.prop | awk -F= '{print $2;}'`" >>$log_file
				    cat $sub_scripts_path/boeffla/2.`grep selected.2= $props_path/boeffla.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
				fi;
				if [ "`grep selected.3= $props_path/boeffla.prop | awk -F= '{print $2;}'`" != "" ]
				  then
				    echo "     Headphones Output  = `grep selected.3= $props_path/boeffla.prop | awk -F= '{print $2;}'`" >>$log_file
				    cat $sub_scripts_path/boeffla/3.`grep selected.3= $props_path/boeffla.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
				fi;
				if [ "`grep selected.4= $props_path/boeffla.prop | awk -F= '{print $2;}'`" != "" ]
				  then
				    echo "     Equalizer Mode     = `grep selected.4= $props_path/boeffla.prop | awk -F= '{print $2;}'`" >>$log_file
				    cat $sub_scripts_path/boeffla/4.`grep selected.4= $props_path/boeffla.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
				fi;
				if [ "`grep selected.5= $props_path/boeffla.prop | awk -F= '{print $2;}'`" != "" ]
				  then
				    echo "     Equalizer Setting  = `grep selected.5= $props_path/boeffla.prop | awk -F= '{print $2;}'`" >>$log_file
				    cat $sub_scripts_path/boeffla/5.`grep selected.5= $props_path/boeffla.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
				fi;
				if [ "`grep selected.6= $props_path/boeffla.prop | awk -F= '{print $2;}'`" != "" ]
				  then
				    echo "     Privacy Mode       = `grep selected.6= $props_path/boeffla.prop | awk -F= '{print $2;}'`" >>$log_file
				    cat $sub_scripts_path/boeffla/6.`grep selected.6= $props_path/boeffla.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
				fi;
				if [ "`grep selected.7= $props_path/boeffla.prop | awk -F= '{print $2;}'`" != "" ]
				  then
				    echo "     DAC direct         = `grep selected.7= $props_path/boeffla.prop | awk -F= '{print $2;}'`" >>$log_file
				    cat $sub_scripts_path/boeffla/7.`grep selected.7= $props_path/boeffla.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
				fi;
				if [ "`grep selected.8= $props_path/boeffla.prop | awk -F= '{print $2;}'`" != "" ]
				  then
				    echo "     DAC 128bit ov.samp.= `grep selected.8= $props_path/boeffla.prop | awk -F= '{print $2;}'`" >>$log_file
				    cat $sub_scripts_path/boeffla/8.`grep selected.8= $props_path/boeffla.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
				fi;
				if [ "`grep selected.9= $props_path/boeffla.prop | awk -F= '{print $2;}'`" != "" ]
				  then
				    echo "     FLL clock tuning   = `grep selected.9= $props_path/boeffla.prop | awk -F= '{print $2;}'`" >>$log_file
				    cat $sub_scripts_path/boeffla/9.`grep selected.9= $props_path/boeffla.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
				fi;
				if [ "`grep selected.10= $props_path/boeffla.prop | awk -F= '{print $2;}'`" != "" ]
				  then
				    echo "     Speaker tuning     = `grep selected.10= $props_path/boeffla.prop | awk -F= '{print $2;}'`" >>$log_file
				    cat $sub_scripts_path/boeffla/10.`grep selected.10= $props_path/boeffla.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
				fi;
		fi;
fi;

# Finish adding the script footer ----------------------------------------------------------------

cat $sub_scripts_path/footer >>$script_path/$script_name

# Installing generated script to system init -----------------------------------------------------

echo "" >>$log_file
echo "Installing generated script to /system/etc" >>$log_file

rm /system/etc/$script_name
cp $script_path/$script_name /system/etc/$script_name
chmod 755 /system/etc/$script_name
chown 0:2000 /system/etc/$script_name

# Keep a backup of the prop files
rm -rf /data/yank555.lu-debug
mkdir /data/yank555.lu-debug
cp $props_path/*.prop /data/yank555.lu-debug

# All done for this step -------------------------------------------------------------------------